"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DropdownMultiselectOption = void 0;
const React = require("react");
class DropdownMultiselectOptionComponent extends React.Component {
    constructor() {
        super(...arguments);
        this.handleChange = (event, option) => {
            const { onChange, selected, setSelected } = this.props;
            const currentSelected = [...selected];
            if (event.currentTarget.checked) {
                currentSelected.push(option);
            }
            else {
                const index = currentSelected.findIndex(opt => this.getKey(opt) === this.getKey(option));
                currentSelected.splice(index, 1);
            }
            setSelected(currentSelected);
            if (onChange !== undefined) {
                onChange(currentSelected);
            }
        };
        this.getKey = (value) => {
            const { getOptionKey } = this.props;
            if (getOptionKey) {
                return getOptionKey(value);
            }
            if (typeof value === 'string') {
                return value;
            }
            return value.key ? value.key : '';
        };
        this.getValue = (value) => {
            const { getOptionKey } = this.props;
            if (getOptionKey) {
                return getOptionKey(value);
            }
            if (typeof value === 'string') {
                return value;
            }
            return value.label ? value.label : '';
        };
    }
    render() {
        const { options, name, selected } = this.props;
        return (React.createElement(React.Fragment, null, options &&
            options.map((option, index) => {
                return (React.createElement("div", { key: index, className: "dropdown-item" },
                    React.createElement("div", { className: "form-check" },
                        React.createElement("input", { value: this.getKey(option), id: `multiselect-${name}-${index}`, className: "form-check-input", type: "checkbox", name: `${name}`, onChange: (event) => this.handleChange(event, option), checked: selected.findIndex(opt => this.getKey(opt) === this.getKey(option)) > -1 }),
                        React.createElement("label", { className: "form-check-label", style: { userSelect: 'none', width: '100%' }, htmlFor: `multiselect-${name}-${index}` }, this.getValue(option)))));
            })));
    }
}
exports.DropdownMultiselectOption = DropdownMultiselectOptionComponent;
